@@ -30,6 +30,7 @@ var Cancel goContext.CancelFunc
 type App struct {
 	OverrideKubeContext        string
 	OverrideHelmBinary         string
+	OverrideKustomizeBinary    string
 	EnableLiveOutput           bool
 	StripArgsValuesOnExitError bool
 	DisableForceUpdate         bool
@@ -74,6 +75,7 @@ func New(conf ConfigProvider) *App {
 	return Init(&App{
 		OverrideKubeContext:        conf.KubeContext(),
 		OverrideHelmBinary:         conf.HelmBinary(),
+		OverrideKustomizeBinary:    conf.KustomizeBinary(),
 		EnableLiveOutput:           conf.EnableLiveOutput(),
 		StripArgsValuesOnExitError: conf.StripArgsValuesOnExitError(),
 		DisableForceUpdate:         conf.DisableForceUpdate(),
@@ -660,11 +662,10 @@ func (a *App) list(run *Run) ([]*HelmRelease, error) {
 			return nil, err
 		}
 
-		installed := r.Installed == nil || *r.Installed
 		releases = append(releases, &HelmRelease{
 			Name:      r.Name,
 			Namespace: r.Namespace,
-			Installed: installed,
+			Installed: r.Desired(),
 			Enabled:   enabled,
 			Labels:    labels,
 			Chart:     r.Chart,
@@ -758,11 +759,12 @@ func (a *App) loadDesiredStateFromYaml(file string, opts ...LoadOpts) (*state.He
 		logger:    a.Logger,
 		remote:    a.remote,
 
-		overrideKubeContext: a.OverrideKubeContext,
-		overrideHelmBinary:  a.OverrideHelmBinary,
-		enableLiveOutput:    a.EnableLiveOutput,
-		getHelm:             a.getHelm,
-		valsRuntime:         a.valsRuntime,
+		overrideKubeContext:     a.OverrideKubeContext,
+		overrideHelmBinary:      a.OverrideHelmBinary,
+		overrideKustomizeBinary: a.OverrideKustomizeBinary,
+		enableLiveOutput:        a.EnableLiveOutput,
+		getHelm:                 a.getHelm,
+		valsRuntime:             a.valsRuntime,
 	}
 
 	return ld.Load(file, op)
@@ -1320,7 +1322,7 @@ func (a *App) apply(r *Run, c ApplyConfigProvider) (bool, bool, []error) {
 	st := r.state
 	helm := r.helm
 
-	helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+	helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state, nil)...)
 
 	selectedReleases, selectedAndNeededReleases, err := a.getSelectedReleases(r, c.IncludeTransitiveNeeds())
 	if err != nil {
@@ -1371,7 +1373,8 @@ func (a *App) apply(r *Run, c ApplyConfigProvider) (bool, bool, []error) {
 
 	// join --args and --diff-args together to one string.
 	args := strings.Join([]string{c.Args(), c.DiffArgs()}, " ")
-	helm.SetExtraArgs(argparser.GetArgs(args, r.state)...)
+	argsOpts := &argparser.GetArgsOptions{WithDiffArgs: true}
+	helm.SetExtraArgs(argparser.GetArgs(args, r.state, argsOpts)...)
 
 	infoMsg, releasesToBeUpdated, releasesToBeDeleted, errs := r.diff(false, detailedExitCode, c, diffOpts)
 	if len(errs) > 0 {
@@ -1567,7 +1570,7 @@ Do you really want to delete?
 `, strings.Join(names, "\n"))
 	interactive := c.Interactive()
 	if !interactive || interactive && r.askForConfirmation(msg) {
-		r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+		r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state, nil)...)
 
 		if len(releasesToDelete) > 0 {
 			_, deletionErrs := withDAG(st, helm, a.Logger, state.PlanOptions{SelectedReleases: toDelete, Reverse: true, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
@@ -1593,7 +1596,8 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 		helm := r.helm
 
 		args := strings.Join([]string{c.Args(), c.DiffArgs()}, " ")
-		helm.SetExtraArgs(argparser.GetArgs(args, r.state)...)
+		argsOpts := &argparser.GetArgsOptions{WithDiffArgs: true}
+		helm.SetExtraArgs(argparser.GetArgs(args, r.state, argsOpts)...)
 
 		var errs []error
 
@@ -1617,7 +1621,7 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 		}
 		infoMsg, updated, deleted, errs = filtered.diff(true, c.DetailedExitcode(), c, opts)
 
-		helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+		helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state, argsOpts)...)
 		return errs
 	})
 
@@ -1630,7 +1634,7 @@ func (a *App) lint(r *Run, c LintConfigProvider) (bool, []error, []error) {
 	ok, errs := a.withNeeds(r, c, false, func(st *state.HelmState) []error {
 		helm := r.helm
 
-		args := argparser.GetArgs(c.Args(), st)
+		args := argparser.GetArgs(c.Args(), st, nil)
 
 		// Reset the extra args if already set, not to break `helm fetch` by adding the args intended for `lint`
 		helm.SetExtraArgs()
@@ -1680,7 +1684,7 @@ func (a *App) status(r *Run, c StatusesConfigProvider) (bool, []error) {
 
 	var toStatus []state.ReleaseSpec
 	for _, r := range selectedReleases {
-		if r.Installed != nil && !*r.Installed {
+		if !r.Desired() {
 			continue
 		}
 		toStatus = append(toStatus, r)
@@ -1691,7 +1695,7 @@ func (a *App) status(r *Run, c StatusesConfigProvider) (bool, []error) {
 	// Traverse DAG of all the releases so that we don't suffer from false-positive missing dependencies
 	st.Releases = allReleases
 
-	args := argparser.GetArgs(c.Args(), st)
+	args := argparser.GetArgs(c.Args(), st, nil)
 
 	// Reset the extra args if already set, not to break `helm fetch` by adding the args intended for `lint`
 	helm.SetExtraArgs()
@@ -1824,7 +1828,7 @@ Do you really want to sync?
 
 	var errs []error
 
-	r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+	r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state, nil)...)
 
 	// Traverse DAG of all the releases so that we don't suffer from false-positive missing dependencies
 	st.Releases = selectedAndNeededReleases
@@ -1891,7 +1895,7 @@ func (a *App) template(r *Run, c TemplateConfigProvider) (bool, []error) {
 	return a.withNeeds(r, c, false, func(st *state.HelmState) []error {
 		helm := r.helm
 
-		args := argparser.GetArgs(c.Args(), st)
+		args := argparser.GetArgs(c.Args(), st, nil)
 
 		// Reset the extra args if already set, not to break `helm fetch` by adding the args intended for `lint`
 		helm.SetExtraArgs()
@@ -2014,7 +2018,7 @@ func (a *App) test(r *Run, c TestConfigProvider) []error {
 	// with conditions and selectors
 	st.Releases = toTest
 
-	r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+	r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state, nil)...)
 
 	return st.TestReleases(r.helm, cleanup, timeout, concurrency, state.Logs(c.Logs()))
 }
