@@ -13,8 +13,10 @@ import (
 
 // GlobalOptions is the global configuration for the Helmfile CLI.
 type GlobalOptions struct {
-	// helmBinary is the path to the Helm binary.
+	// HelmBinary is the path to the Helm binary.
 	HelmBinary string
+	// KustomizeBinary is the path to the Kustomize binary.
+	KustomizeBinary string
 	// File is the path to the Helmfile.
 	File string
 	// Environment is the name of the environment to use.
@@ -93,6 +95,11 @@ func (g *GlobalImpl) HelmBinary() string {
 	return g.GlobalOptions.HelmBinary
 }
 
+// KustomizeBinary returns the path to the Kustomize binary.
+func (g *GlobalImpl) KustomizeBinary() string {
+	return g.GlobalOptions.KustomizeBinary
+}
+
 // KubeContext returns the name of the kubectl context to use.
 func (g *GlobalImpl) KubeContext() string {
 	return g.GlobalOptions.KubeContext
