@@ -34,17 +34,18 @@ type FileSystem struct {
 	Getwd             func() (string, error)
 	Chdir             func(string) error
 	Abs               func(string) (string, error)
+	EvalSymlinks      func(string) (string, error)
 }
 
 func DefaultFileSystem() *FileSystem {
 	dfs := FileSystem{
-		ReadDir:    os.ReadDir,
-		DeleteFile: os.Remove,
-		Stat:       os.Stat,
-		Glob:       filepath.Glob,
-		Getwd:      os.Getwd,
-		Chdir:      os.Chdir,
-		Abs:        filepath.Abs,
+		ReadDir:      os.ReadDir,
+		DeleteFile:   os.Remove,
+		Stat:         os.Stat,
+		Glob:         filepath.Glob,
+		Getwd:        os.Getwd,
+		Chdir:        os.Chdir,
+		EvalSymlinks: filepath.EvalSymlinks,
 	}
 
 	dfs.Stat = dfs.stat
@@ -52,6 +53,7 @@ func DefaultFileSystem() *FileSystem {
 	dfs.FileExistsAt = dfs.fileExistsAtDefault
 	dfs.DirectoryExistsAt = dfs.directoryExistsDefault
 	dfs.FileExists = dfs.fileExistsDefault
+	dfs.Abs = dfs.absDefault
 	return &dfs
 }
 
@@ -91,7 +93,9 @@ func FromFileSystem(params FileSystem) *FileSystem {
 	if params.Abs != nil {
 		dfs.Abs = params.Abs
 	}
-
+	if params.EvalSymlinks != nil {
+		dfs.EvalSymlinks = params.EvalSymlinks
+	}
 	return dfs
 }
 
@@ -110,13 +114,20 @@ func (filesystem *FileSystem) readFile(name string) ([]byte, error) {
 }
 
 func (filesystem *FileSystem) fileExistsAtDefault(path string) bool {
+	path, err := filesystem.resolveSymlinks(path)
+	if err != nil {
+		return false
+	}
 	fileInfo, err := filesystem.Stat(path)
 	return err == nil && fileInfo.Mode().IsRegular()
 }
 
 func (filesystem *FileSystem) fileExistsDefault(path string) (bool, error) {
-	_, err := filesystem.Stat(path)
-
+	path, err := filesystem.resolveSymlinks(path)
+	if err != nil {
+		return false, err
+	}
+	_, err = filesystem.Stat(path)
 	if err != nil {
 		if os.IsNotExist(err) {
 			return false, nil
@@ -127,6 +138,38 @@ func (filesystem *FileSystem) fileExistsDefault(path string) (bool, error) {
 }
 
 func (filesystem *FileSystem) directoryExistsDefault(path string) bool {
+	path, err := filesystem.resolveSymlinks(path)
+	if err != nil {
+		return false
+	}
 	fileInfo, err := filesystem.Stat(path)
 	return err == nil && fileInfo.Mode().IsDir()
 }
+
+func (filesystem *FileSystem) resolveSymlinks(path string) (string, error) {
+	if !filepath.IsAbs(path) && !filepath.IsLocal(path) {
+		basePath, err := filesystem.Getwd()
+		if err != nil {
+			return "", err
+		}
+
+		basePath, err = filesystem.EvalSymlinks(basePath)
+		if err != nil {
+			return "", err
+		}
+		path, err := filesystem.EvalSymlinks(filepath.Join(basePath, path))
+		if err != nil {
+			return "", err
+		}
+		return path, nil
+	}
+	return path, nil
+}
+
+func (filesystem *FileSystem) absDefault(path string) (string, error) {
+	path, err := filesystem.resolveSymlinks(path)
+	if err != nil {
+		return "", err
+	}
+	return filepath.Abs(path)
+}
